@@ -1,10 +1,14 @@
 # Author: Jason Dsouza
 # Github: http://www.github.com/jasmcaus
 
-from ._version import version as v
-from ._version import author as __author__
+from ._meta import version as v
+from ._meta import author as __author__
+from ._meta import release as r
+from ._meta import contributors as c
 version = v
 __version__ = v
+release = r
+contributors = c
 
 from .preprocess import preprocess_from_dir
 from .preprocess import sep_train
@@ -33,5 +37,9 @@ from .opencv import to_rgb
 from .opencv import url_to_image 
 from .opencv import translate
 from .opencv import rotate 
-from .opencv import rotate_bound 
-from .opencv import canny 
\ No newline at end of file
+from .opencv import canny 
+
+from .visualizations import hex_to_rgb
+from .visualizations import draw_rectangle
+
+from .io_disk import read_image
\ No newline at end of file
