@@ -6,20 +6,21 @@ import sys
 sys.path.append('..')
 
 import os
+import random
 import time
 import numpy as np
 from .utils import readImg, saveNumpy, get_classes_from_dir
-from .preprocessing import MeanProcess
+from .preprocessing import MeanProcess, _check_mean_sub_values
 
 def preprocess_from_dir(DIR, 
                         classes=None, 
                         channels=1, 
-                        IMG_SIZE=224, 
-                        train_size=None, 
+                        IMG_SIZE=(224,224), 
+                        per_class_size=None, 
                         normalize_train=False, 
                         mean_subtraction=None, 
                         isShuffle=True, 
-                        save_train=False, 
+                        save_data=False, 
                         destination_filename=None, 
                         verbose=1):
     """
@@ -27,63 +28,71 @@ def preprocess_from_dir(DIR,
     @param DIR: Directory 
     @param classes --> A list of folder names within `DIR`
     @param channels: Number of channels each image will be processed to (default: 1)
-    :param train_size: Size of the training set
+    :param per_class_size: Intended size of the each class to be preprocessed
     :param normalize_train: Whether to normalize each image to between [0,1]
     :param mean_subtraction: Whether mean subtraction should be applied (Tuple)
     :param isShuffle: Shuffle the training set
-    :param save_train: If True, saves the training set as a .npy or .npz file based on destination_filename
-    :param destination_filename: if save_train is True, the train set will be saved as the filename specified
+    :param save_data: If True, saves the training set as a .npy or .npz file based on destination_filename
+    :param destination_filename: if save_data is True, the train set will be saved as the filename specified
     :param verbose: Integer either 0 (verbosity off) or 1 (verbosity on). Displays the progress to the terminal as preprocessing continues. Default = 1
     
-    :return train: Image Pixel Values with corresponding labels (float32)
+    :return data: Image Pixel Values with corresponding labels (float32)
     :return classes: ONLY if `classes=None`
-    Saves the above variables as .npy files if `save_train = True`
+    Saves the above variables as .npy files if `save_data = True`
     """
-    return_classes = False
-    train = [] 
+    return_classes_flag = False
+    data = [] 
+
+    if not os.path.exists(DIR):
+        raise ValueError('[ERROR] The specified directory does not exist')
+
+    if IMG_SIZE is None:
+        raise ValueError('[ERROR] IMG_SIZE must be specified')
+
+    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
+        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2 (width,height)')
+
     if verbose in [0,1]:
         if verbose == 0:
             display_count = False
         else:
             display_count = True
+    
+    if verbose not in [0,1]:
+        raise ValueError('[ERROR] verbose flag must be either 1 (display progress to terminal) or 0 otherwise')
+
+    if type(save_data) is not bool:
+        raise ValueError('[ERROR] save_data is a boolean (True/False)')
 
     if classes is None:
-        return_classes = True
+        return_classes_flag = True
 
-    if save_train:
-        if destination_filename is None:
-            raise TypeError('[ERROR] Specify a destination file name')
-
-        elif not ('.npy' in destination_filename or '.npz' in destination_filename):
-            raise ValueError('[ERROR] Specify the correct numpy destination file extension (.npy or .npz)', destination_filename)
-    
-        elif destination_filename is not None:
-            destination_filename = None
-    
     if classes is not None and type(classes) is not list:
         raise ValueError('[ERROR] "classes" must be a list')
 
-    if not os.path.exists(DIR):
-        raise ValueError('[ERROR] The specified directory does not exist', DIR)
+    if save_data:
+        if destination_filename is None:
+            raise ValueError('[ERROR] Specify a destination file name')
 
-    if IMG_SIZE is None:
-        raise ValueError('[ERROR] IMG_SIZE must be specified')
-
-    if type(IMG_SIZE) is not int:
-        raise ValueError('[ERROR] IMG_SIZE must be an integer')
+        elif not ('.npy' in destination_filename or '.npz' in destination_filename):
+            raise ValueError('[ERROR] Specify the correct numpy destination file extension (.npy or .npz)')
+    
+    if not save_data and destination_filename is not None:
+        destination_filename = None
+    
 
     # Loading from Numpy Files
     if destination_filename is not None and os.path.exists(destination_filename):
         since = time.time()
         print('[INFO] Loading from Numpy Files')
-        train = np.load(destination_filename, allow_pickle=True)
+        data = np.load(destination_filename, allow_pickle=True)
         end = time.time()
         print('----------------------------------------------')
         print('[INFO] Loaded in {:.0f}s from Numpy Files'.format(end-since))
 
-        return train
+        return data
 
-    # Extracting image data
+    # Extracting image data and adding to `data`
     else:
         since_preprocess = time.time()
         if destination_filename is not None:
@@ -95,36 +104,38 @@ def preprocess_from_dir(DIR,
         if classes is None:
             classes = get_classes_from_dir(DIR)
 
-        if train_size is None:
-            train_size = len(os.listdir(os.path.join(DIR, classes[0])))
+        if per_class_size is None:
+            per_class_size = len(os.listdir(os.path.join(DIR, classes[0])))
 
-        # Checking if 'mean_subtraction' values are valid. Returns boolean value
-        subtract_mean = check_mean_subtraction(mean_subtraction, channels)
+        if mean_subtraction is not None:
+            # Checking if 'mean_subtraction' values are valid. Returns boolean value
+            subtract_mean = _check_mean_sub_values(mean_subtraction, channels)
 
         for item in classes:
             class_path = os.path.join(DIR, item)
             class_label = classes.index(item)
             count = 0 
             for image in os.listdir(class_path):
-                if count != train_size:
+                if count != per_class_size:
                     image_path = os.path.join(class_path, image)
 
-                    # Returns image RESIZED and img
+                    # Returns the resized image
                     img = readImg(image_path, resized_img_size=IMG_SIZE, channels=channels)
                     if img is None:
                         continue
+
                     # Normalizing
                     if normalize_train:
                         img = normalize(img)
                     
                     # Subtracting Mean
                     # Mean must be calculated ONLY on the training set
-                    if subtract_mean:
+                    if mean_subtraction is not None and subtract_mean:
                         mean_subtract = MeanProcess(mean_subtraction, channels)
                         img = mean_subtract.mean_preprocess(img, channels)
                         
                     # Appending to train set
-                    train.append([img, class_label])
+                    data.append([img, class_label])
                     count +=1 
 
                     if display_count is True:
@@ -134,13 +145,13 @@ def preprocess_from_dir(DIR,
 
         # Shuffling the Training Set
         if isShuffle is True:
-            train = shuffle(train)
+            data = shuffle(data)
 
         # Converting to Numpy
-        train = np.array(train)
+        data = np.array(data)
 
-        # Saves the Train set as a .npy file
-        if save_train is True:
+        # Saves the Data set as a .npy file
+        if save_data:
             #Converts to Numpy and saves
             if destination_filename.endswith('.npy'):
                 print('[INFO] Saving as .npy file')
@@ -149,7 +160,7 @@ def preprocess_from_dir(DIR,
             
             since = time.time()
             # Saving
-            saveNumpy(destination_filename, train)
+            saveNumpy(destination_filename, data)
             end = time.time()
             
             time_elapsed = end-since
@@ -160,51 +171,42 @@ def preprocess_from_dir(DIR,
         end_preprocess = time.time()
         time_elapsed_preprocess = end_preprocess-since_preprocess
         print('----------------------------------------------')
-        print('[INFO] Preprocessing complete! Took {:.0f}m {:.0f}s'.format(time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
+        print('[INFO] {} files preprocessed! Took {:.0f}m {:.0f}s'.format(count, time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
 
-        if return_classes:
-            return train, classes
+        if return_classes_flag:
+            return data, classes
         else:
-            return train
+            return data
+
 
 def _printTotal(count, category):
     print(f'{count} - {category}')
 
-def check_mean_subtraction(value, channels):
-    """
-        Checks if mean subtraction values are valid based on the number of channels
-        Must be a tuple of dimensions = number of channels
-    Returns boolean value
-        True -> Expression is valid
-        False -> Expression is invalid
-    """
-    if value is None:
-        return False
-    elif type(value) is tuple and len(value) == channels:
-        return True
-    else:
-        raise ValueError(f'[ERROR] Expected a tuple of dimension {channels}', value) 
 
-def shuffle(train):
+def shuffle(data):
     """
     Shuffles the Array
     """
-    import random
-    random.shuffle(train)
-    return train
+    random.shuffle(data)
+    return data
 
-def sep_train(train, IMG_SIZE=None, channels=1):
+
+def sep_train(data, IMG_SIZE, channels=1):
     # x = []
     # y = []
-    # for feature, label in train:
+    # for feature, label in data:
     #     x.append(feature)
     #     y.append(label)
     
     if IMG_SIZE is None:
         raise ValueError('[ERROR] IMG_SIZE not defined')
+
+    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
+        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2')
+
     else:
-        x = [i[0] for i in train]
-        y = [i[1] for i in train]
+        x = [i[0] for i in data]
+        y = [i[1] for i in data]
 
         # Without reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE)
         # On reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE,channels)
@@ -215,8 +217,17 @@ def sep_train(train, IMG_SIZE=None, channels=1):
 
         return x, y
 
+
 def reshape(x, IMG_SIZE, channels):
-    return np.array(x).reshape(-1, IMG_SIZE, IMG_SIZE, channels)
+    if IMG_SIZE is None:
+        raise ValueError('[ERROR] IMG_SIZE not defined')
+
+    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
+        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2')
+
+    width, height = IMG_SIZE[:2]
+    return np.array(x).reshape(-1, width, height, channels)
+
 
 def normalize(x, dtype='float32'):
     """
@@ -227,4 +238,4 @@ def normalize(x, dtype='float32'):
     
     # Converting to float32 and normalizing (float32 saves memory)
     x = x.astype(dtype) / 255
-    return x
\ No newline at end of file
+    return x
