@@ -8,18 +8,14 @@ import os
 import cv2 as cv
 import numpy as np
 from ._split import train_test_split
+from .io_disk import read_image
 
-# # For Python 2.7
-# import sys
-# if sys.version_info.major == 2:
-#     from urllib2 import urlopen
-# For Python
 
 def readImg(image_path, resized_img_size=None, channels=1):
-    if not os.path.exists(image_path):
-        raise FileNotFoundError('[ERROR] The image file was not found')
+    if type(resized_img_size) is not tuple or len(resized_img_size) != 2:
+        raise ValueError('[ERROR] resized_img_size must be a tuple of size 2 (width,height')
 
-    image_array = cv.imread(image_path)
+    image_array = read_image(image_path)
 
     # [INFO] Using the following piece of code results in a 'None' in the training set
     # if image_array == None:
@@ -27,9 +23,10 @@ def readImg(image_path, resized_img_size=None, channels=1):
     if channels == 1:
         image_array = cv.cvtColor(image_array, cv.COLOR_BGR2GRAY)
     if resized_img_size is not None:
-        image_array = cv.resize(image_array, (resized_img_size,resized_img_size))
+        image_array = cv.resize(image_array, resized_img_size)
     return image_array
 
+
 def get_classes_from_dir(DIR):
     if len(os.listdir(DIR)) == 0:
         raise ValueError('[ERROR] The specified directory does not seem to have any folders in it')
@@ -38,25 +35,25 @@ def get_classes_from_dir(DIR):
         return classes
         
 
-def saveNumpy(name, x):
+def saveNumpy(base_name, data):
     """
     Saves an array to a .npy file
     Converts to Numpy (if not already)
     """
 
-    x = np.array(x)
-    if '.npy' in name:
-        np.save(name, x)
-    elif '.npz' in name:
-        np.savez_compressed(name, x)
+    data = np.array(data)
+    if '.npy' in base_name:
+        np.save(base_name, data)
+    elif '.npz' in base_name:
+        np.savez_compressed(base_name, data)
 
 
-def train_val_split(X,y,val_ratio=.2):
+def train_val_split(X, y, val_ratio=.2):
     """
     Do not use if mean subtraction is being employed
     Returns X_train, X_val, y_train, y_val
     """
-    X_train, X_val, y_train, y_val = train_test_split(X,y,test_size=val_ratio)
+    X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=val_ratio)
     return X_train, X_val, y_train, y_val
 
 
@@ -64,8 +61,11 @@ def sort_dict(unsorted_dict, descending=False):
     """ 
     Sorts a dictionary in ascending order (if descending = False) or descending order (if descending = True)
     """
+    if type(descending) is not bool:
+        raise ValueError('[ERROR] `descending` must be a boolean')
     return sorted(unsorted_dict.items(), key=lambda x:x[1], reverse=descending)
 
+
 def plotAcc(histories):
     """
     Plots the model accuracies as 2 graphs
